from setuptools import setup

setup(name='gaussian_binomial_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['gaussian_binomial_distributions'],
      zip_safe=False)
